/*******************
 VARIABLES
*******************/
var lastModified = "2017-04-18";
var lastUploaded = "2017-04-18";

var templateVersion = "2.0.23";
var dimensions;
var scrollPos = {
	x: 0,
	y: 0
};

var adId, rnd, uid;
var closeButton;
var userActionButton;
var clickthroughButton;
var useSingleCreative = true;
var snapPoints = [0, 628, 824, 951, 1119, 1272];
var wasPanelLoadReported = false;
var wasPanelClosed = false;

/*******************
 INITIALIZATION
*******************/
function checkIfAdKitReady(event) {
	try {
		if(window.localPreview) {
			window.initializeLocalPreview(); //in localPreview.js
			initializeCreative();
			return;
		}
	}
	catch(e) {}

	adkit.onReady(initializeCreative);
	setColumnWithDelays();
}

function initializeCreative(event) {
	// so messaging can work in safe frames we need to bind the events that are present in the event manager.
	try {
		EBG.pm.bind("sendCreativeId", function () {
			eventManager.apply(this, arguments);
		}, this);
		EBG.pm.bind("eventCallback", function () {
			eventManager.apply(this, arguments);
		}, this);
	}
	catch(e) {}

	//Workaround (from QB6573) for Async EB Load where Modernizr isn't properly initialized
	typeof Modernizr == "object" && (Modernizr.touch = Modernizr.touch || "ontouchstart" in window);
	initializeGlobalVariables();
	window.registerInteraction = function () {}; //overwrite rI function because it will never actually be called
	displayDimensions();
	addEventListeners();
	trackVideoInteractions();
	initAnimation("INIT_PANEL_EXPANSION");
	if(localPreview) {
		closeButton.style.display = "block";
	}
	else {
		closeButton.style.display = "none";
	}
	setColumnWithDelays();
}

function initializeGlobalVariables() {
	adId = EB._adConfig.adId;
	rnd = EB._adConfig.rnd;
	uid = EB._adConfig.uid;
	closeButton = document.getElementById("close-button");
	userActionButton = document.getElementById("user-action-button");
	clickthroughButton = document.getElementById("clickthrough-button");
}

function addEventListeners() {
	userActionButton.addEventListener("click", userAction);
	clickthroughButton.addEventListener("click", clickthrough);
	closeButton.addEventListener("click", collapse);
}

function removeEventListeners() {
	window.removeEventListener("resize", setColumn);
	window.removeEventListener("resize", updateAdDimensions);
}

//this function will be invoked when the expand animation starts
function expandAnimStart(event) {
	
}

//this function will be invoked when the collapse animation starts
function collapseAnimStart(event) {
	closeButton.style.display = "none";
}

//this function will be invoked when the expand animation has finished
function expandAnimComplete(event) {
	checkCloseEnabled();
	checkIfVisibleOnLoad();
}

//this function will be invoked when the collapse animation has finished
function collapseAnimComplete(event) {
	if(!wasPanelClosed){
		wasPanelClosed=true;
		//put your code here
	}
}

function checkCloseEnabled() {
	if(!EB._adConfig.customJSVars.mdCloseButtonShow) {
		closeButton.style.display = "none";
	}
	else {
		closeButton.style.display = "block";
	}
}

function checkIfVisibleOnLoad() {
	if(isFirstExpansion()) {
		if(isAdVisible()) {
			if(!wasPanelLoadReported) {
				wasPanelLoadReported = true;
				EB.automaticEventCounter("Billboard_Load");
			}
		}
		else {
			window.addEventListener("resize", checkIfVisible);
		}
	}
}

function checkIfVisible(event) {
	if(isAdVisible()) {
		EB.automaticEventCounter("Ad_Resize_AdShown");
		window.removeEventListener("resize", checkIfVisible);
	}
}

function isAdVisible() {
	return window.innerWidth > 0 && window.innerHeight > 0;
}

function isFirstExpansion() {
	return EB._adConfig && EB._adConfig.customJSVars && EB._adConfig.customJSVars.mdIsFirstExpand;
}

/*******************
 EVENT HANDLERS
*******************/

function userAction(event) {
	EB.userActionCounter("UserAction");
}

function clickthrough(event) {
	pauseVideos();
	EB.clickthrough();
}

function collapse(event) {
	pauseVideos();
	initAnimation("COLLAPSE_BILLBOARD");
	if(localPreview) {
		EB.expand({
			panelName: EB._adConfig.customJSVars.mdLeaveBehindPanelName
		});
	}
}


function onPageScroll(event) {
	scrollPos.x = event.scrollXPercent;
	scrollPos.y = event.scrollYPercent;
	displayDimensions();
}

/*******************
 UTILITIES
*******************/
function getVideos() {
	var videos = document.getElementsByTagName("video");
	return videos;
}

function trackVideoInteractions() {
	var videos = getVideos();

	for(var i = 0; i < videos.length; i++) {
		var videoTrackingModule = new EBG.VideoModule(videos[i]);
	}
}

function pauseVideos() {
	var videos = getVideos();
	for(var i = 0; i < videos.length; i++) {
		videos[i].pause();
	}
}

function setColumn() {
	if(useSingleCreative) {
		setSingleColumn();
	}
	else {
		setAllColumns();
	}
	if(window.innerWidth === 0 || window.innerHeight === 0) {
		try {
			pauseVideos();
		}
		catch(error) {}
	}
}

function setColumnWithDelays() {
	setColumn();
	setTimeout(setColumn, 100);
	setTimeout(setColumn, 500);
}

function setSingleColumn() {
	// Refer the maximum creative dimension to use scale down for the entire dimensions for responsive feather. 
	//For example if maximum creative dimension is 1272x328. 
	document.getElementById('ad_content').style.width = "1272px";
	document.getElementById('ad_content').style.height = "328px";

	//After removing two pixels from width and height which is used for boder, dimension remains is 1270x326. Use this dimension in the belo calulation function.

	var scaleRatioW = calculateAspectRatioFit(1270, 326, document.getElementById('column').clientWidth, document.getElementById('column').clientHeight);

	document.getElementById('ad_content').style.webkitTransform = 'scale(' + scaleRatioW.ratio + ')';
	document.getElementById('ad_content').style.MozTransform = 'scale(' + scaleRatioW.ratio + ')';
	document.getElementById('ad_content').style.msTransform = 'scale(' + scaleRatioW.ratio + ')';
	document.getElementById('ad_content').style.OTransform = 'scale(' + scaleRatioW.ratio + ')';
	document.getElementById('ad_content').style.transform = 'scale(' + scaleRatioW.ratio + ')';

	document.getElementById('ad_content').style.webkitTransformOrigin = '0 0';
	document.getElementById('ad_content').style.MozTransformOrigin = '0 0';
	document.getElementById('ad_content').style.msTransformOrigin = '0 0';
	document.getElementById('ad_content').style.OTransformOrigin = '0 0';
	document.getElementById('ad_content').style.transformOrigin = '0 0';
}

function calculateAspectRatioFit(srcWidth, srcHeight, maxWidth, maxHeight) {
	var ratio = Math.min(maxWidth / srcWidth, maxHeight / srcHeight);
	return {
		ratio: ratio
	};
}

function setAllColumns() {
	setCurrentColumn(getEnumeratedPanelMetricsIndex());
}

function setCurrentColumn(n) {
	for(var i = 1; i < snapPoints.length; i++) {
		document.getElementById(("column") + i).style.display = "none";
	}
	try {
		document.getElementById(("column") + n).style.display = "block";
	}
	catch(error) {}
}

function getEnumeratedPanelMetricsIndex() {
	var w = document.getElementById("billboard").offsetWidth;
	for(var i = 2; i < snapPoints.length; i++) {
		if(w < snapPoints[i]) break;
	}
	return(i - 1);
}

function displayAdDimensions(event) {
	billboard = document.getElementById("billboard");
	dimensionsSpan = document.getElementById("dimensions");

	if(billboard && dimensionsSpan) {
		window.addEventListener("resize", updateAdDimensions);
		updateAdDimensions();
	}
}

function updateAdDimensions(event) {
	dimensionsSpan.innerHTML = ", " + billboard.offsetWidth + "x" + billboard.offsetHeight;
}

function displayDimensions() {
	if(dimensions) {
		var iw = window.innerWidth,
			ih = window.innerHeight,
			sx = scrollPos.x,
			sy = scrollPos.y;
		var str = "<br>Viewport: " + iw + "x" + ih + " | <span style='display:block'>Scroll (X: " + sx + "%; Y: " + sy + "%)</span>";
		dimensions.innerHTML = str;
	}
}

/*********************************
HTML5 Event System - Do Not Modify
*********************************/
var listenerQueue;
var creativeIFrameId;

function sendMessage(type, data) {
	if(!data.type) data.type = type;
	EB._sendMessage(type, data);
}

function addCustomScriptEventListener(eventName, callback, interAd) {
	listenerQueue = listenerQueue || {};
	var data = {
		uid: uid,
		listenerId: Math.ceil(Math.random() * 1000000000),
		eventName: eventName,
		interAd: !!(interAd),
		creativeIFrameId: creativeIFrameId
	};
	sendMessage("addCustomScriptEventListener", data);
	data.callback = callback;
	listenerQueue[data.listenerId] = data;
	return data.listenerId;
}

function dispatchCustomScriptEvent(eventName, params) {
	params = params || {};
	params.uid = uid;
	params.eventName = eventName;
	params.creativeIFrameId = creativeIFrameId;
	sendMessage("dispatchCustomScriptEvent", params);
}

function removeCustomScriptEventListener(listenerId) {
	var params = {
		uid: uid,
		listenerId: listenerId,
		creativeIFrameId: creativeIFrameId
	};
	sendMessage("removeCustomScriptEventListener", params);

	if(listenerQueue[listenerId])
		delete listenerQueue[listenerId];
}

function initAnimation(eventName) {
	var params = params || {};
	params.eventName = eventName;
	params.panelName = EB._adConfig.customJSVars.mdBillboardPanelName;
	sendMessage('dispatchCustomScriptEvent', params);
}

function eventManager(event) {
	var msg;
	if(typeof event == "object" && event.data) {
		msg = JSON.parse(event.data);
	}
	else {
		// this is safe frame.
		msg = {
			type: event.type,
			data: event
		};
	}

	if(msg.type && msg.data && (!uid || (msg.data.uid && msg.data.uid == uid))) {
		switch(msg.type) {
		case "sendCreativeId":
			creativeIFrameId = msg.data.creativeIFrameId;
			addCustomScriptEventListener('pageScroll', onPageScroll);
			addCustomScriptEventListener("EXPAND_ANIM_START", expandAnimStart, false);
			addCustomScriptEventListener("COLLAPSE_ANIM_START", collapseAnimStart, false);
			addCustomScriptEventListener("EXPAND_ANIM_COMPLETE", expandAnimComplete, false);
			addCustomScriptEventListener("COLLAPSE_ANIM_COMPLETE", collapseAnimComplete, false);
			sendMessage("dispatchScrollPos", {
				uid: uid
			});
			if(creativeContainerReady)
				creativeContainerReady();
			break;
		case "eventCallback": // Handle Callback
			var list = msg.data.listenerIds;
			var length = list.length;
			for(var i = 0; i < length; i++) {
				try {

					var t = listenerQueue[list[i]];
					if(!t) continue;
					t.callback(msg.data);
				}
				catch(e) {}
			}
			break;
		}
	}
}

window.addEventListener("message", function () {
	try {
		eventManager.apply(this, arguments);
	}
	catch(e) {}
}, false);
/*************************************
End HTML5 Event System - Do Not Modify
*************************************/
window.addEventListener("DOMContentLoaded", checkIfAdKitReady);
window.addEventListener("resize", setColumn);
window.addEventListener("load", displayAdDimensions);
window.addEventListener("unload", removeEventListeners);